"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Input = exports.Label = exports.RadioMark = exports.Root = exports.RadioGroupRoot = void 0;

var _index = require("../styles/index");

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function getBorderColor(props) {
  var $checked = props.$checked,
      $isError = props.$isError,
      $theme = props.$theme;
  var colors = $theme.colors;
  return $isError ? colors.negative400 : $checked ? colors.primary400 : colors.mono700;
}

function getLabelPadding(props) {
  var _props$$labelPlacemen = props.$labelPlacement,
      $labelPlacement = _props$$labelPlacemen === void 0 ? '' : _props$$labelPlacemen,
      $theme = props.$theme;
  var scale200 = $theme.sizing.scale200;
  var paddingSide = 'padding' + $labelPlacement.replace(/^\w/, function (c) {
    return c.toUpperCase();
  });
  return _defineProperty({}, paddingSide, scale200);
}

function getLabelColor(props) {
  var $disabled = props.$disabled,
      $theme = props.$theme;
  var colors = $theme.colors;
  return $disabled ? colors.mono600 : colors.mono1000;
}

var RadioGroupRoot = (0, _index.styled)('div', function (props) {
  var $disabled = props.$disabled,
      $align = props.$align;
  return {
    flexDirection: $align === 'horizontal' ? 'row' : 'column',
    display: 'flex',
    alignItems: $align === 'horizontal' ? 'center' : 'flex-start',
    cursor: $disabled ? 'not-allowed' : 'pointer'
  };
});
exports.RadioGroupRoot = RadioGroupRoot;
var Root = (0, _index.styled)('label', function (props) {
  var $disabled = props.$disabled,
      $labelPlacement = props.$labelPlacement;
  return {
    flexDirection: $labelPlacement === 'top' || $labelPlacement === 'bottom' ? 'column' : 'row',
    display: 'flex',
    alignItems: 'center',
    cursor: $disabled ? 'not-allowed' : 'pointer'
  };
});
exports.Root = Root;
var RadioMark = (0, _index.styled)('span', function (props) {
  var $checked = props.$checked,
      $disabled = props.$disabled,
      $theme = props.$theme,
      $isFocused = props.$isFocused,
      $isError = props.$isError;
  var colors = $theme.colors,
      animation = $theme.animation;
  var _$theme$sizing = $theme.sizing,
      scale0 = _$theme$sizing.scale0,
      scale100 = _$theme$sizing.scale100,
      scale300 = _$theme$sizing.scale300,
      scale600 = _$theme$sizing.scale600;
  var activeStyle = {
    backgroundColor: $checked || $isError ? null : $isFocused ? colors.mono500 : !$disabled && !$checked ? colors.mono400 : null
  };
  return {
    backgroundColor: 'transparent',
    borderRadius: '50%',
    borderWidth: $checked ? scale300 : scale0,
    width: $checked ? scale100 : scale600,
    height: $checked ? scale100 : scale600,
    backgroundImage: null,
    flex: '0 0 auto',
    transitionDuration: animation.timing100,
    transitionTimingFunction: animation.easeOutCurve,
    borderStyle: 'solid',
    borderColor: getBorderColor(props),
    display: 'inline-block',
    verticalAlign: 'middle',
    backgroundRepeat: 'no-repeat',
    backgroundPosition: 'center',
    marginTop: $theme.sizing.scale200,
    marginBottom: $theme.sizing.scale200,
    marginLeft: $theme.sizing.scale200,
    marginRight: $theme.sizing.scale200,
    ':hover': activeStyle,
    ':active': activeStyle
  };
});
exports.RadioMark = RadioMark;
var Label = (0, _index.styled)('div', function (props) {
  var typography = props.$theme.typography;
  return _objectSpread({
    verticalAlign: 'middle'
  }, getLabelPadding(props), {
    color: getLabelColor(props)
  }, typography.font400);
}); // tricky style for focus event cause display: none doesn't work

exports.Label = Label;
var Input = (0, _index.styled)('input', {
  opacity: 0,
  width: 0,
  overflow: 'hidden',
  margin: 0,
  padding: 0
});
exports.Input = Input;