"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _index = require("../index");

var _menu = require("../../menu");

var _constants = require("../constants");

var _tag = require("../../tag");

var _constants2 = require("../../menu/constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function sleep(ms) {
  return new Promise(function (resolve) {
    setTimeout(resolve, ms);
  });
}

describe('Stateless select', function () {
  var wrapper,
      events = {};
  var allProps = {},
      mockFn;
  beforeEach(function () {
    mockFn = jest.fn();
    events = {
      onChange: jest.fn(),
      onTextInputChange: jest.fn(),
      onMouseEnter: mockFn,
      onMouseLeave: mockFn,
      onFocus: mockFn,
      onBlur: mockFn
    };
    allProps = _objectSpread({}, events);
  });
  afterEach(function () {
    jest.restoreAllMocks();
    wrapper && wrapper.unmount();
  });
  test.each([[_constants.TYPE.search, false], [_constants.TYPE.select, false], [_constants.TYPE.search, true], [_constants.TYPE.select, true]])('should render component in %s mode and %s for multiple choice', function (type, multiple) {
    allProps.type = type;
    allProps.multiple = multiple;
    wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
    expect(wrapper).toMatchSnapshot('Component has correct render in ' + type + ' mode and mutiple choice equal ' + multiple);
  });
  describe('events', function () {
    var documentMock, instance, originalAddEventListener, originalRemoveEventListener;
    beforeEach(function () {
      /* eslint-disable-next-line cup/no-undef  */
      documentMock = document;
      originalAddEventListener = documentMock.addEventListener;
      originalRemoveEventListener = documentMock.removeEventListener; //$FlowFixMe

      documentMock.addEventListener = jest.fn(); //$FlowFixMe

      documentMock.removeEventListener = jest.fn();
      wrapper = (0, _enzyme.shallow)(_react.default.createElement(_index.Select, allProps));
      instance = wrapper.instance();
    });
    afterEach(function () {
      //$FlowFixMe
      documentMock.addEventListener = originalAddEventListener; //$FlowFixMe

      documentMock.removeEventListener = originalRemoveEventListener;
    });
    test('should subscribe on document click to handle toggle of dropdown when component is rendered', function () {
      expect(documentMock.addEventListener).toHaveBeenCalledWith('click', instance.handleClickEvent, {
        capture: true
      });
    });
    test('should unsubscribe from document click to handle toggle of dropdown when component is removed from DOM', function () {
      wrapper.unmount();
      expect(documentMock.removeEventListener).toHaveBeenCalledWith('click', instance.handleClickEvent, {
        capture: true
      });
    });
    test('should close dropdown if clicked outside of select component', function () {
      wrapper.unmount();
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
      instance = wrapper.instance();
      instance.setState({
        isDropDownOpen: true
      });
      instance.handleClickEvent({
        target: null
      });
      expect(instance.state.isDropDownOpen).toBeFalsy();
    });
    test('should call onTextInputChange when input value changes', function () {
      var textValue = 'test';
      allProps.type = _constants.TYPE.search;
      allProps.onTextInputChange = jest.fn();
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
      var e = {
        target: {
          value: textValue
        }
      };
      wrapper.instance().onTextInputChange(e);
      expect(allProps.onTextInputChange).toHaveBeenCalledWith(e);
    });
  });
  describe('Selected Tags', function () {
    var clearIcon;
    var selectedOptions;
    var options;
    beforeEach(function () {
      selectedOptions = [{
        id: '2',
        label: 'label for 2'
      }];
      options = [{
        id: '1',
        label: 'label for 1'
      }, {
        id: '2',
        label: 'label for 2'
      }];
      allProps = Object.assign({}, allProps, {
        options: options,
        selectedOptions: selectedOptions,
        type: _constants.TYPE.search,
        multiple: true
      });
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
    });
    test('should remove selected tag from selected options if X button is clicked', function () {
      clearIcon = wrapper.find(_tag.StyledAction);
      clearIcon.first().simulate('click');
      expect(allProps.onChange.mock.calls[0][0]).toEqual({
        type: _constants.STATE_CHANGE_TYPE.unselect,
        option: allProps.selectedOptions[0],
        selectedOptions: [],
        event: expect.anything()
      });
    });
    test('should should clear all selected tags when Clear All clicked', function () {
      wrapper.unmount();
      allProps.selectedOptions = options;
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
      clearIcon = wrapper.find(_index.StyledSelectComponentIcon);
      clearIcon = clearIcon.filterWhere(function (comp) {
        return comp.props().$type === _constants.ICON.clearAll;
      });
      clearIcon.first().simulate('click');
      expect(allProps.onChange.mock.calls[0][0]).toEqual({
        type: _constants.STATE_CHANGE_TYPE.unselect,
        selectedOptions: [],
        event: expect.anything()
      });
    });
  });
  describe('Search mode', function () {
    test('should call text input change method when change of input happened', function () {
      allProps = Object.assign({}, allProps, {
        type: _constants.TYPE.search,
        multiple: true
      });
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
      var value = 'some input value';
      var input = wrapper.find(_index.StyledInput).first().find('input');
      var event = {
        target: {
          value: value
        }
      };
      input.props().onChange(event);
      expect(wrapper.instance().props.onTextInputChange).toHaveBeenCalledWith(event);
    });
    test('should support simple filtering',
    /*#__PURE__*/
    _asyncToGenerator(
    /*#__PURE__*/
    regeneratorRuntime.mark(function _callee() {
      var onTextInputChangePromise, input;
      return regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              allProps = Object.assign({}, allProps, {
                type: _constants.TYPE.search,
                filterable: true,
                options: jest.fn()
              });
              onTextInputChangePromise = Promise.resolve([{
                id: 'aaa',
                label: 'AAA'
              }, {
                id: 'aab',
                label: 'AAB'
              }, {
                id: 'abb',
                label: 'ABB'
              }]);
              allProps.options.mockReturnValue(onTextInputChangePromise);
              wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
              input = wrapper.find(_index.StyledInput).first().find('input');
              input.simulate('change', {
                target: {
                  value: 'a'
                }
              });
              _context.next = 8;
              return sleep(1);

            case 8:
              wrapper.update();
              expect(wrapper.find(_index.StyledOption)).toHaveLength(3);
              input.simulate('change', {
                target: {
                  value: 'aa'
                }
              });
              _context.next = 13;
              return sleep(1);

            case 13:
              wrapper.update();
              expect(wrapper.find(_index.StyledOption)).toHaveLength(2);
              input.simulate('change', {
                target: {
                  value: 'aaa'
                }
              });
              _context.next = 18;
              return sleep(1);

            case 18:
              wrapper.update();
              expect(wrapper.find(_index.StyledOption)).toHaveLength(1);
              input.simulate('change', {
                target: {
                  value: 'aaaa'
                }
              });
              _context.next = 23;
              return sleep(1);

            case 23:
              wrapper.update();
              expect(wrapper.find(_index.StyledOption)).toHaveLength(0);

            case 25:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    })));
    test('should support select and deselect',
    /*#__PURE__*/
    _asyncToGenerator(
    /*#__PURE__*/
    regeneratorRuntime.mark(function _callee2() {
      var input, renderOptions, selected;
      return regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              allProps = Object.assign({}, allProps, {
                type: _constants.TYPE.search,
                multiple: true,
                options: [{
                  id: 'red',
                  label: 'Red'
                }, {
                  id: 'green',
                  label: 'Green'
                }, {
                  id: 'blue',
                  label: 'Blue'
                }]
              });
              wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
              input = wrapper.find(_index.StyledInput).first().find('input'); // Type some characters to get items to show

              input.props().onChange({
                target: {
                  value: 'e'
                }
              });
              _context2.next = 6;
              return sleep(1);

            case 6:
              wrapper.update();
              renderOptions = wrapper.find(_menu.StyledListItem);
              selected = []; // Test a sequence of select/deselects

              [{
                index: 0,
                type: _constants.STATE_CHANGE_TYPE.select
              }, {
                index: 2,
                type: _constants.STATE_CHANGE_TYPE.select
              }, {
                index: 0,
                type: _constants.STATE_CHANGE_TYPE.unselect
              }].forEach(function (event) {
                // Click the specific option
                renderOptions.at(event.index).simulate('click');
                var toggledOption = allProps.options[event.index];

                if (event.type === _constants.STATE_CHANGE_TYPE.select) {
                  selected.push(toggledOption);
                } else {
                  selected = selected.filter(function (o) {
                    return o.id !== toggledOption.id;
                  });
                }

                expect(allProps.onChange).toHaveBeenLastCalledWith({
                  type: event.type,
                  option: toggledOption,
                  selectedOptions: selected,
                  event: expect.anything()
                });
                wrapper.setProps({
                  selectedOptions: selected
                });
              });

            case 10:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2, this);
    })));
    test('should support custom filter option',
    /*#__PURE__*/
    _asyncToGenerator(
    /*#__PURE__*/
    regeneratorRuntime.mark(function _callee3() {
      var onTextInputChangePromise, input;
      return regeneratorRuntime.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              allProps = Object.assign({}, allProps, {
                type: _constants.TYPE.search,
                filterable: true,
                getOptionLabel: function getOptionLabel(option) {
                  return option.label.title;
                },
                options: [{
                  id: 'a',
                  label: {
                    title: 'foo',
                    subtitle: 'bar'
                  }
                }, {
                  id: 'b',
                  label: {
                    title: 'abc',
                    subtitle: 'bar'
                  }
                }],
                filterOption: jest.fn().mockImplementation(function (option, query) {
                  return option.label.title.indexOf(query) >= 0 || option.label.subtitle.indexOf(query) >= 0;
                })
              });
              onTextInputChangePromise = Promise.resolve();
              allProps.onTextInputChange.mockReturnValue(onTextInputChangePromise);
              wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
              input = wrapper.find(_index.StyledInput).first().find('input');
              input.simulate('change', {
                target: {
                  value: 'xyz'
                }
              });
              _context3.next = 8;
              return sleep(1);

            case 8:
              wrapper.update();
              expect(wrapper.find(_index.StyledOption).length).toBe(0);
              input.simulate('change', {
                target: {
                  value: 'ar'
                }
              });
              _context3.next = 13;
              return sleep(1);

            case 13:
              wrapper.update();
              expect(wrapper.find(_index.StyledOption).length).toBe(2);

            case 15:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3, this);
    })));
    test('backspace should delete last selected option in multiple mode', function () {
      var options = [{
        id: 'red',
        label: 'Red'
      }, {
        id: 'green',
        label: 'Green'
      }, {
        id: 'blue',
        label: 'Blue'
      }];
      allProps = _objectSpread({}, allProps, {
        onChange: jest.fn(),
        type: _constants.TYPE.search,
        multiple: true,
        options: options,
        selectedOptions: options.slice(0, 2)
      });
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
      expect(wrapper.find(_tag.StyledAction).length).toBe(2);
      wrapper.find('input').simulate('keydown', {
        key: _constants2.KEY_STRINGS.Backspace
      });
      expect(allProps.onChange).toHaveBeenCalledTimes(1);
      expect(allProps.onChange.mock.calls[0][0]).toEqual({
        type: _constants.STATE_CHANGE_TYPE.unselect,
        option: options[1],
        selectedOptions: [options[0]],
        event: expect.anything()
      });
    });
  });
  describe('Select mode', function () {
    test('should toggle dropdown if input is clicked', function () {
      allProps = Object.assign({}, allProps, {
        type: _constants.TYPE.select
      });
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
      expect(wrapper.instance().state.isDropDownOpen).toBeFalsy();
      wrapper.find(_index.StyledInput).first().simulate('click');
      expect(wrapper.instance().state.isDropDownOpen).toBeTruthy();
    });
    test('should support single select', function () {
      allProps.options = [{
        id: 'red',
        label: 'Red'
      }];
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
      wrapper.find(_index.StyledInput).first().simulate('click');
      wrapper.find(_menu.StyledListItem).at(0).simulate('click');
      expect(allProps.onChange).toHaveBeenLastCalledWith({
        type: _constants.STATE_CHANGE_TYPE.select,
        option: allProps.options[0],
        selectedOptions: [allProps.options[0]],
        event: expect.anything()
      });
    });
  }); //$FlowFixMe

  describe.each([[_constants.TYPE.search], [_constants.TYPE.select]])('hot keys in %s mode of component', function (mode) {
    test.each([[_constants2.KEY_STRINGS.ArrowDown, 'open dropdown', {
      isDropDownOpen: true
    }], [_constants2.KEY_STRINGS.Space, 'open dropdown', {
      isDropDownOpen: mode === _constants.TYPE.select
    }], [_constants2.KEY_STRINGS.Escape, 'close dropdown', {
      isDropDownOpen: false
    }]])('when pressed key "%s" should %s', function (hotKey, result, newState) {
      allProps.selectedOptions = [{
        id: '123',
        label: 'label for 123'
      }];
      allProps = Object.assign({}, allProps, {
        type: mode,
        multiple: true,
        options: [{
          id: '1',
          label: 'foo1'
        }]
      });
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Select, allProps));
      var input = wrapper.find(_index.StyledInput).first().find('input');
      input.simulate('keydown', {
        key: hotKey
      });
      expect(wrapper.instance().state).toMatchObject(newState);
    });
  });
});