"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _index = require("../index");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
jest.useFakeTimers();
describe('Toast', function () {
  test('basic functionality', function () {
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Toast, null, "Notification"));
    expect(wrapper.instance().state.isHidden).toBe(false);
    expect(wrapper.instance().state.isAnimating).toBe(true);
    expect(wrapper.find(_index.StyledBody).first()).toExist();
    expect(wrapper.find(_index.StyledCloseIcon).first()).toExist();
  });
  test('Body component props', function () {
    var renderedRoot;
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Toast, null, "Notification"));
    renderedRoot = wrapper.find(_index.StyledBody).first();
    expect(renderedRoot).toExist();
    expect(renderedRoot.props().$kind).toBe(_index.KIND.info);
    expect(renderedRoot.props().$closeable).toBe(true);
    expect(renderedRoot.props().$isHidden).toBe(false);
    expect(renderedRoot.props().$isAnimating).toBe(true); // pass new kind value set to KIND.positive
    // and closeable set to false

    wrapper.setProps({
      kind: _index.KIND.positive,
      closeable: false
    });
    renderedRoot = wrapper.find(_index.StyledBody).first();
    expect(renderedRoot.props().$kind).toBe(_index.KIND.positive);
    expect(renderedRoot.props().$closeable).toBe(false); // pass new kind value set to KIND.warning

    wrapper.setProps({
      kind: _index.KIND.warning
    });
    renderedRoot = wrapper.find(_index.StyledBody).first();
    expect(renderedRoot.props().$kind).toBe(_index.KIND.warning); // pass new kind value set to KIND.negative

    wrapper.setProps({
      kind: _index.KIND.negative
    });
    renderedRoot = wrapper.find(_index.StyledBody).first();
    expect(renderedRoot.props().$kind).toBe(_index.KIND.negative);
  });
  test('close icon rendering', function () {
    var renderedCloseButton;
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Toast, null, "Notification"));
    renderedCloseButton = wrapper.find(_index.StyledCloseIcon).first();
    expect(renderedCloseButton).toExist(); // pass new closeable value set to false

    wrapper.setProps({
      closeable: false
    });
    renderedCloseButton = wrapper.find(_index.StyledCloseIcon).first();
    expect(renderedCloseButton).not.toExist();
  });
  test('close icon props', function () {
    var renderedCloseButton;
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Toast, null, "Notification"));
    renderedCloseButton = wrapper.find(_index.StyledCloseIcon).first();
    expect(renderedCloseButton.props().onClick).toBe(wrapper.instance().dismiss);
    expect(renderedCloseButton.props().$kind).toBe(_index.KIND.info); // pass new kind value set to KIND.positive

    wrapper.setProps({
      kind: _index.KIND.positive
    });
    renderedCloseButton = wrapper.find(_index.StyledCloseIcon).first();
    expect(renderedCloseButton.props().$kind).toBe(_index.KIND.positive); // pass new kind value set to KIND.warning

    wrapper.setProps({
      kind: _index.KIND.warning
    });
    renderedCloseButton = wrapper.find(_index.StyledCloseIcon).first();
    expect(renderedCloseButton.props().$kind).toBe(_index.KIND.warning); // pass new kind value set to KIND.negative

    wrapper.setProps({
      kind: _index.KIND.negative
    });
    renderedCloseButton = wrapper.find(_index.StyledCloseIcon).first();
    expect(renderedCloseButton.props().$kind).toBe(_index.KIND.negative);
  });
  test('onClose handler', function () {
    var props = {
      onClose: jest.fn()
    };
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Toast, props, "Notification"));
    var closeButton = wrapper.find(_index.StyledCloseIcon).first();
    expect(closeButton).toExist();
    closeButton.simulate('click');
    expect(wrapper.instance().state.isHidden).toBe(true);
    expect(wrapper.instance().state.isAnimating).toBe(true);
    expect(props.onClose).not.toHaveBeenCalled();
    jest.runAllTimers();
    expect(setTimeout).toHaveBeenLastCalledWith(expect.any(Function), 600);
    expect(wrapper.instance().state.isAnimating).toBe(false);
    expect(props.onClose).toHaveBeenCalled();
  });
  test('onMouseEnter handler', function () {
    var props = {
      onMouseEnter: jest.fn()
    };
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Toast, props, "Notification"));
    var renderedRoot = wrapper.find(_index.StyledBody).first();
    var toastOnMouseEnterHandler = wrapper.instance().onMouseEnter;
    expect(renderedRoot.props().onMouseEnter).toBe(toastOnMouseEnterHandler);
    expect(renderedRoot.props().onMouseEnter).not.toBe(props.onMouseEnter);
    toastOnMouseEnterHandler({});
    expect(props.onMouseEnter).toHaveBeenCalled();
  });
  test('onMouseLeave handler', function () {
    var props = {
      onMouseLeave: jest.fn()
    };
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Toast, props, "Notification"));
    var renderedRoot = wrapper.find(_index.StyledBody).first();
    var toastOnMouseLeaveHandler = wrapper.instance().onMouseLeave;
    expect(renderedRoot.props().onMouseLeave).not.toBe(props.onMouseLeave);
    expect(renderedRoot.props().onMouseLeave).toBe(toastOnMouseLeaveHandler);
    toastOnMouseLeaveHandler({});
    expect(props.onMouseLeave).toHaveBeenCalled();
  });
  test('onFocus handler', function () {
    var props = {
      onFocus: jest.fn()
    };
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Toast, props, "Notification"));
    var renderedRoot = wrapper.find(_index.StyledBody).first();
    var toastOnFocusHandler = wrapper.instance().onFocus;
    expect(renderedRoot.props().onFocus).not.toBe(props.onFocus);
    expect(renderedRoot.props().onFocus).toBe(toastOnFocusHandler);
    toastOnFocusHandler({});
    expect(props.onFocus).toHaveBeenCalled();
  });
  test('onBlur handler', function () {
    var props = {
      onBlur: jest.fn()
    };
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.Toast, props, "Notification"));
    var renderedRoot = wrapper.find(_index.StyledBody).first();
    var toastOnBlurHandler = wrapper.instance().onBlur;
    expect(renderedRoot.props().onBlur).not.toBe(props.onBlur);
    expect(renderedRoot.props().onBlur).toBe(toastOnBlurHandler);
    toastOnBlurHandler({});
    expect(props.onBlur).toHaveBeenCalled();
  });
  test('component overrides', function () {
    var overrides = {
      Body: jest.fn().mockImplementation(function (_ref) {
        var children = _ref.children;
        return _react.default.createElement("span", null, children);
      }),
      CloseIcon: {
        props: {
          size: '54px'
        },
        style: {
          color: 'red'
        },
        component: jest.fn().mockImplementation(function (_ref2) {
          var children = _ref2.children;
          return _react.default.createElement("svg", null, children);
        })
      }
    };
    var wrapper = (0, _enzyme.mount)( // $FlowFixMe
    _react.default.createElement(_index.Toast, {
      overrides: overrides
    }, "Notification"));
    var bodyOverride = wrapper.find(overrides.Body);
    expect(bodyOverride).toHaveLength(1);
    var closeIconOverride = wrapper.find(overrides.CloseIcon.component);
    expect(closeIconOverride).toHaveLength(1);
    expect(closeIconOverride.props().$size).toBe('54px');
    expect(closeIconOverride.props().$style).toBe(overrides.CloseIcon.style);
  });
});