"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

describe('Stateful checkbox', function () {
  var allProps, wrapper;
  beforeEach(function () {
    allProps = {};
    jest.mock('../select', function () {
      return jest.fn(function () {
        return _react.default.createElement("div", null, "test");
      });
    });
  });
  afterEach(function () {
    jest.restoreAllMocks();
    wrapper && wrapper.unmount();
  });
  test('should provide default styled components to render', function () {
    var _require = require('../index'),
        StyledRoot = _require.StyledRoot,
        StyledInput = _require.StyledInput,
        StyledInputContainer = _require.StyledInputContainer,
        StyledSelectComponentIcon = _require.StyledSelectComponentIcon,
        StyledDropDown = _require.StyledDropDown,
        StyledOption = _require.StyledOption,
        StyledDropDownItem = _require.StyledDropDownItem,
        StatefulSelect = _require.StatefulSelect;

    var _require2 = require('../../tag'),
        Tag = _require2.Tag;

    allProps.overrides = {
      Root: StyledRoot,
      Input: StyledInput,
      InputContainer: StyledInputContainer,
      Tag: Tag,
      SelectComponentIcon: StyledSelectComponentIcon,
      DropDown: StyledDropDown,
      Option: StyledOption,
      DropDownItem: StyledDropDownItem
    };

    var checkbox = require('../select');

    wrapper = (0, _enzyme.mount)(_react.default.createElement(StatefulSelect, allProps));
    var overrides = checkbox.mock.calls[0][0].overrides;
    expect(overrides).toEqual({
      Root: StyledRoot,
      Input: StyledInput,
      InputContainer: StyledInputContainer,
      Tag: Tag,
      SelectComponentIcon: StyledSelectComponentIcon,
      DropDown: StyledDropDown,
      Option: StyledOption,
      DropDownItem: StyledDropDownItem
    });
  });
  test('should pass all the other props to stateless select', function () {
    var otherProps = {
      someProp: 'some other props',
      autoFocus: false
    };
    allProps = _objectSpread({}, allProps, otherProps);

    var _require3 = require('../index'),
        StatefulSelect = _require3.StatefulSelect;

    var select = require('../select');

    wrapper = (0, _enzyme.mount)(_react.default.createElement(StatefulSelect, allProps)); // eslint-disable-next-line no-unused-vars

    var _select$mock$calls$1$ = select.mock.calls[1][0],
        overrides = _select$mock$calls$1$.overrides,
        rest = _objectWithoutProperties(_select$mock$calls$1$, ["overrides"]);

    expect(rest).toMatchObject({
      someProp: 'some other props',
      selectedOptions: [],
      autoFocus: false
    });
  });
});