"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _index = require("../index");

var _constants = require("../constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
describe('Select styled components', function () {
  describe('StyledInput', function () {
    test('Input', function () {
      var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StyledInput, null, _react.default.createElement("div", null)));
      expect(component.instance().getStyles()).toMatchSnapshot('StyledInput has correct styles');
    });
  });
  describe('StyledInputContainer', function () {
    test('InputContainer', function () {
      var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StyledInputContainer, null, _react.default.createElement("div", null)));
      expect(component.instance().getStyles()).toMatchSnapshot('StyledInputContainer has correct styles');
    });
  });
  describe('StyledSelectComponentIcon', function () {
    test.each([[_constants.ICON.clearAll], [_constants.ICON.select], [_constants.ICON.loop], [_constants.ICON.selected]])('', function ($type) {
      var props = {
        $type: $type
      };
      var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StyledSelectComponentIcon, props, _react.default.createElement("div", null)));
      expect(component.instance().getStyles()).toMatchSnapshot('StyledSelectComponentIcon has correct styles when type is ' + $type);
    });
  });
  describe('StyledDropDown', function () {
    test.each([['', ''], ['$type', _constants.TYPE.select], ['$isOpen', true]])('', function (prop, value) {
      var props = {};
      props[prop] = value;
      var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StyledDropDown, props, _react.default.createElement("div", null)));
      expect(component.instance().getStyles()).toMatchSnapshot("StyledDropDown has correct styles when ".concat(prop, " is ").concat(value));
    });
  });
  describe('StyledDropDownItem', function () {
    test('DropDownItem', function () {
      var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StyledDropDownItem, null, _react.default.createElement("div", null)));
      expect(component.instance().getStyles()).toMatchSnapshot('StyledDropDownItem has correct styles');
    });
  });
  describe('StyledOption', function () {
    test.each([[''], ['disabled'], ['$selected']])('', function (prop) {
      var props = {};
      props[prop] = true;
      var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StyledOption, props, _react.default.createElement("div", null)));
      expect(component.instance().getStyles()).toMatchSnapshot('StyledOption has correct styles when ' + prop);
    });
  });
});